summaryrefslogtreecommitdiffstats
path: root/src/mesa/drivers/dri/i965/brw_state_upload.c
diff options
context:
space:
mode:
authorJordan Justen <jordan.l.justen@intel.com>2015-03-07 20:20:03 -0800
committerJordan Justen <jordan.l.justen@intel.com>2015-03-31 16:40:23 -0700
commit2c02baa4870cf08592ac64a576fd6a73262892fb (patch)
tree4f7bbc218ecbd69de0cd204d893afeac1a27569f /src/mesa/drivers/dri/i965/brw_state_upload.c
parent611bd80f3b4972622a9f2c155c95d3241668e4d9 (diff)
downloadexternal_mesa3d-2c02baa4870cf08592ac64a576fd6a73262892fb.zip
external_mesa3d-2c02baa4870cf08592ac64a576fd6a73262892fb.tar.gz
external_mesa3d-2c02baa4870cf08592ac64a576fd6a73262892fb.tar.bz2
i965/state: Rename brw_upload_state to brw_upload_render_state
Signed-off-by: Jordan Justen <jordan.l.justen@intel.com> Reviewed-by: Kristian Høgsberg <krh@bitplanet.net> Reviewed-by: Kenneth Graunke <kenneth@whitecape.org>
Diffstat (limited to 'src/mesa/drivers/dri/i965/brw_state_upload.c')
-rw-r--r--src/mesa/drivers/dri/i965/brw_state_upload.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mesa/drivers/dri/i965/brw_state_upload.c b/src/mesa/drivers/dri/i965/brw_state_upload.c
index e446de6..542600f 100644
--- a/src/mesa/drivers/dri/i965/brw_state_upload.c
+++ b/src/mesa/drivers/dri/i965/brw_state_upload.c
@@ -579,7 +579,7 @@ brw_upload_programs(struct brw_context *brw)
/***********************************************************************
* Emit all state:
*/
-void brw_upload_state(struct brw_context *brw)
+void brw_upload_render_state(struct brw_context *brw)
{
struct gl_context *ctx = &brw->ctx;
struct brw_state_flags *state = &brw->state.dirty;
@@ -686,11 +686,11 @@ void brw_upload_state(struct brw_context *brw)
/**
* Clear dirty bits to account for the fact that the state emitted by
* brw_upload_state() has been committed to the hardware. This is a separate
* call from brw_upload_state() because it's possible that after the call to
* brw_upload_state(), we will discover that we've run out of aperture space,
* and need to rewind the batch buffer to the state it had before the
* brw_upload_state() call.
*/
void
brw_clear_dirty_bits(struct brw_context *brw)
@@ -686,11 +686,11 @@ void brw_upload_state(struct brw_context *brw)
/**
* Clear dirty bits to account for the fact that the state emitted by
- * brw_upload_state() has been committed to the hardware. This is a separate
- * call from brw_upload_state() because it's possible that after the call to
- * brw_upload_state(), we will discover that we've run out of aperture space,
- * and need to rewind the batch buffer to the state it had before the
- * brw_upload_state() call.
+ * brw_upload_render_state() has been committed to the hardware. This is a
+ * separate call from brw_upload_render_state() because it's possible that
+ * after the call to brw_upload_render_state(), we will discover that we've
+ * run out of aperture space, and need to rewind the batch buffer to the state
+ * it had before the brw_upload_render_state() call.
*/
void